==> dasu_3.02.jar: edu/northwestern/dasu/drools/FactDidEvent.java <==
/**
 * Dasu Project
 *
 * File:         FactFireAction.java
 * RCS:          $Id$
 * Description:  FactFireAction class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      May 24, 2010 at 2:22:53 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.drools
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2010, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

package edu.northwestern.dasu.drools;

/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The FactFireAction class ...
 */
public class FactDidEvent extends FactTemplate  {

	private static final long serialVersionUID = 1L;
	
	public String type = "";
	public long downloadId = -1;
	public long timeRecorded = System.currentTimeMillis();
	public long duration = 30000; //milliseconds

	public FactDidEvent() {
	}
	
	public FactDidEvent(String type, long did) {
		this.type = type;
		this.downloadId = did;
	}

	public FactDidEvent(String type, long did, long timeRecorded, long duration) {
		this.type = type;
		this.downloadId = did;
		this.timeRecorded = timeRecorded;
		this.duration = duration;
	}

	public FactDidEvent(String type, long did, long duration) {
		this.type = type;
		this.downloadId = did;
		this.duration = duration;
	}

	public String getType() {
		return type;
	}

	public long getDownloadId() {
		return downloadId;
	}

	public void setType(String type) {
		this.type = type;
	}

	public void setDownloadId(long downloadId) {
		this.downloadId = downloadId;
	}
	
	public long getTimeRecorded() {
		return timeRecorded;
	}

	public void setTimeRecorded(long timeRecorded) {
		this.timeRecorded = timeRecorded;
	}
	
	public long getDuration() {
		return duration;
	}

	public void setDuration(long duration) {
		this.duration = duration;
	}
	
}

==> dasu_5.31.jar: edu/northwestern/dasu/drools/FactDidEvent.java <==
/**
 * Dasu Project
 *
 * File:         FactFireAction.java
 * RCS:          $Id$
 * Description:  FactFireAction class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      May 24, 2010 at 2:22:53 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.drools
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2010, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

package edu.northwestern.dasu.drools;

import edu.northwestern.dasu.util.Util;

/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The FactFireAction class ...
 */
public class FactDidEvent extends FactTemplate  {

	private static final long serialVersionUID = 1L;
	
	public String type = "";
	public long downloadId = -1;
	public long timeRecorded = Util.currentTimeMillis();	
	public long duration = 30000; //milliseconds

	public FactDidEvent() {
	}
	
	public FactDidEvent(String type, long did) {
		this.type = type;
		this.downloadId = did;
	}

	public FactDidEvent(String type, long did, long timeRecorded, long duration) {
		this.type = type;
		this.downloadId = did;
		this.timeRecorded = timeRecorded;
		this.duration = duration;
	}

	public FactDidEvent(String type, long did, long duration) {
		this.type = type;
		this.downloadId = did;
		this.duration = duration;
	}

	public String getType() {
		return type;
	}

	public long getDownloadId() {
		return downloadId;
	}

	public void setType(String type) {
		this.type = type;
	}

	public void setDownloadId(long downloadId) {
		this.downloadId = downloadId;
	}
	
	public long getTimeRecorded() {
		return timeRecorded;
	}

	public void setTimeRecorded(long timeRecorded) {
		this.timeRecorded = timeRecorded;
	}
	
	public long getDuration() {
		return duration;
	}

	public void setDuration(long duration) {
		this.duration = duration;
	}
	
}
